@@ -487,8 +487,8 @@ gtk_plot_canvas_child_set_property (GObject      *object,
 static void
 gtk_plot_canvas_child_init(GtkPlotCanvasChild *child)
 {
-  child->flags = GTK_PLOT_CANVAS_CAN_MOVE | 
-                 GTK_PLOT_CANVAS_CAN_RESIZE;
+  child->flags = GTK_PLOT_CANVAS_CHILD_CAN_MOVE | 
+                 GTK_PLOT_CANVAS_CHILD_CAN_RESIZE;
 
   child->min_width = -1;
   child->min_height = -1;
@@ -670,120 +670,106 @@ gtk_plot_canvas_class_init (GtkPlotCanvasClass *klass)
   klass->delete_item = NULL;
   klass->select_region = NULL;
 
+  GParamSpec *pspec;
+
   /**
    * GtkPlotCanvas:flags:
    *
-   *
+   * PlotCanvas flags control selection and DND,
+   * see #GtkPlotCanvasFlags.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_FLAGS,
-  g_param_spec_int ("flags",
-                           P_(""),
-                           P_(""),
-                           0,G_MAXINT,0,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_int ("flags", P_("Flags"),
+      P_("Canvas flags"),
+      0,G_MAXINT,0,
+      G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_FLAGS, pspec);
 
   /**
    * GtkPlotCanvas:magnification:
    *
-   *
+   * PlotCanvas magnification factor
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_MAGNIFICATION,
-  g_param_spec_double ("magnification",
-                           P_(""),
-                           P_(""),
-                           0,G_MAXDOUBLE,1.0,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_double ("magnification", P_("Magnification"),
+      P_("Canvas magnification"),
+      0,G_MAXDOUBLE,1.0,
+      G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_MAGNIFICATION, pspec
+  );
 
   /**
    * GtkPlotCanvas:width:
    *
-   *
+   * PlotCanvas width in pixels.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_WIDTH,
-  g_param_spec_int ("width",
-                           P_(""),
-                           P_(""),
-                           0,G_MAXINT,1,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_int ("width", P_("Width"),
+      P_("Canvas width"),
+      0,G_MAXINT,1,
+      G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_WIDTH, pspec);
 
   /**
    * GtkPlotCanvas:height:
    *
-   *
+   * PlotCanvas height in pixels.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_HEIGHT,
-  g_param_spec_int ("height",
-                           P_(""),
-                           P_(""),
-                           0,G_MAXINT,1,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_int ("height", P_("Height"),
+      P_("Canvas height"),
+      0,G_MAXINT,1,
+      G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_HEIGHT, pspec);
 
   /**
    * GtkPlotCanvas:show_grid:
    *
-   *
+   * Show grid lines.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_SHOW_GRID,
-  g_param_spec_boolean ("show_grid",
-                           P_(""),
-                           P_(""),
+  pspec = g_param_spec_boolean ("show_grid", P_("Show grid"),
+                           P_("Show grid"),
                            FALSE,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+                           G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_SHOW_GRID, pspec);
 
   /**
    * GtkPlotCanvas:grid_step:
    *
-   *
+   * Distance between grid lines.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_GRID_STEP,
-  g_param_spec_double ("grid_step",
-                           P_(""),
-                           P_(""),
+  pspec = g_param_spec_double ("grid_step", P_("Grid step"),
+                           P_("Distance between grid lines"),
                            0,G_MAXDOUBLE,0.0,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+                           G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_GRID_STEP, pspec);
 
   /**
    * GtkPlotCanvas:line_grid:
    *
-   *
+   * Line grid pattern.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_LINE_GRID,
-  g_param_spec_pointer ("line_grid",
-                           P_(""),
-                           P_(""),
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_pointer ("line_grid", P_("Line Grid"),
+                           P_("Canvas line grid"),
+                           G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_LINE_GRID, pspec);
 
   /**
    * GtkPlotCanvas:color_bg:
    *
-   *
+   * Background color.
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_COLOR_BG,
-  g_param_spec_pointer ("color_bg",
-                           P_(""),
-                           P_(""),
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+  pspec = g_param_spec_pointer ("color_bg", P_("Background"),
+                           P_("Background color"),
+                           G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_COLOR_BG, pspec);
 
   /**
    * GtkPlotCanvas:transparent:
    *
-   *
+   * Canvas transparency
    **/
-  g_object_class_install_property (gobject_class,
-                           ARG_CANVAS_TRANSPARENT,
-  g_param_spec_boolean ("transparent",
-                           P_(""),
-                           P_(""),
+  pspec = g_param_spec_boolean ("transparent", P_("Transparent"),
+                           P_("Canvas transparency"),
                            TRUE,
-                           G_PARAM_READABLE|G_PARAM_WRITABLE));
+                           G_PARAM_READWRITE);
+  g_object_class_install_property (gobject_class, ARG_CANVAS_TRANSPARENT, pspec);
 }
 
 static void
@@ -922,6 +908,25 @@ gtk_plot_canvas_init (GtkPlotCanvas *plot_canvas)
   plot_canvas->pixmap = NULL;
 }
 
+GtkPlotCanvasFlags gtk_plot_canvas_flags(GtkPlotCanvas *canvas)
+{
+  g_return_val_if_fail(canvas != NULL, 0);
+  return(canvas->flags);
+}
+
+void gtk_plot_canvas_set_flags(GtkPlotCanvas *canvas, GtkPlotCanvasFlags flags)
+{
+  g_return_if_fail(canvas != NULL);
+  canvas->flags |= flags;
+}
+
+void gtk_plot_canvas_unset_flags(GtkPlotCanvas *canvas, GtkPlotCanvasFlags flags)
+{
+  g_return_if_fail(canvas != NULL);
+  canvas->flags &= ~flags;
+}
+
+
 void
 gtk_plot_canvas_set_pc(GtkPlotCanvas *canvas, GtkPlotPC *pc)
 {
@@ -1272,7 +1277,7 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
   canvas = GTK_PLOT_CANVAS(widget);
   gtk_widget_get_pointer(widget, &x, &y);
 
-  if(canvas->active_item && canvas->active_item->flags == GTK_PLOT_CANVAS_FROZEN) return TRUE;
+  if(canvas->active_item && canvas->active_item->flags == GTK_PLOT_CANVAS_CHILD_FROZEN) return TRUE;
 
   if(canvas->active_item){
     area = canvas->active_item->drag_area;
@@ -1341,7 +1346,7 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
 
   switch(canvas->action){
      case GTK_PLOT_CANVAS_ACTION_DRAG:
-       if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_MOVE){
+       if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_MOVE){
          gint dx, dy;
 
          gtk_plot_canvas_child_draw_selection(canvas, canvas->active_item, canvas->drag_area);
@@ -1359,12 +1364,12 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
        switch(canvas->drag_point){
             case GTK_PLOT_CANVAS_TOP_LEFT: 
             case GTK_PLOT_CANVAS_TOP_RIGHT:
-               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                     new_x = MIN(x, pivot_x);
                     new_width = abs(x - pivot_x);
                }
             case GTK_PLOT_CANVAS_TOP:
-               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                     new_y = MIN(y, pivot_y);
                     new_height = abs(y - pivot_y);
                }
@@ -1374,19 +1379,19 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
                break;
             case GTK_PLOT_CANVAS_BOTTOM_LEFT:
             case GTK_PLOT_CANVAS_BOTTOM_RIGHT:
-               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                     new_x = MIN(x, pivot_x);
                     new_width = abs(x - pivot_x);
                }
             case GTK_PLOT_CANVAS_BOTTOM:
-               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                     new_y = MIN(y, pivot_y);
                     new_height = abs(y - pivot_y);
                }
                break;
             case GTK_PLOT_CANVAS_LEFT:
             case GTK_PLOT_CANVAS_RIGHT:
-               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+               if(canvas->active_item && canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                     new_x = MIN(x, pivot_x);
                     new_width = abs(x - pivot_x);
                }
@@ -1404,11 +1409,11 @@ gtk_plot_canvas_motion (GtkWidget *widget, GdkEventMotion *event)
                 gtk_plot_canvas_child_draw_selection(canvas, canvas->active_item, canvas->drag_area);
                 canvas->pointer_x = x;
                 canvas->pointer_y = y;
-                if(canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_MOVE || canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+                if(canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_MOVE || canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                   area.x = new_x;
                   area.y = new_y;
                 }
-                if(canvas->active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE){
+                if(canvas->active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE){
                   area.width = new_width;
                   area.height = new_height;
                 }
@@ -1545,7 +1550,7 @@ gtk_plot_canvas_button_press(GtkWidget *widget, GdkEventButton *event)
                canvas->action = GTK_PLOT_CANVAS_ACTION_DRAG;
                break;
            default:
-               if(active_item->flags & GTK_PLOT_CANVAS_CAN_RESIZE)
+               if(active_item->flags & GTK_PLOT_CANVAS_CHILD_CAN_RESIZE)
                   canvas->action = GTK_PLOT_CANVAS_ACTION_RESIZE;
                else
                   canvas->action = GTK_PLOT_CANVAS_ACTION_DRAG;
