@@ -589,7 +589,7 @@ static void gtk_sheet_column_class_init_properties(GObjectClass *gobject_class)
      */
     pspec = g_param_spec_boolean("visible", "Column is visible",
                                  "Wether the column is visible",
-                                 FALSE,
+                                 TRUE,
                                  G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class,
                                     PROP_SHEET_COLUMN_VISIBLE, pspec);
@@ -691,7 +691,7 @@ gtk_sheet_column_init(GtkSheetColumn *column)
 
     GTK_SHEET_COLUMN_SET_VISIBLE(column, TRUE);
     GTK_SHEET_COLUMN_SET_SENSITIVE(column, TRUE);
-    gtk_widget_set_can_focus(GTK_WIDGET(column), TRUE);
+    GTK_SHEET_COLUMN_SET_CAN_FOCUS(column, TRUE);
 
     gtk_widget_set_has_window(GTK_WIDGET(column), FALSE);
 }
@@ -1073,7 +1073,7 @@ gtk_sheet_set_column_width(GtkSheet *sheet, gint col, guint width)
 
     _gtk_sheet_column_size_request(sheet, col, &min_width);
 
-    if (width < min_width) return;
+    if (width < min_width) width = min_width;
 
     COLPTR(sheet, col)->width = width;
 
